@@ -30,7 +30,7 @@
 
 using namespace Kerfuffle;
 
-class LibArchiveInterface: public ReadOnlyArchiveInterface
+class LibArchiveInterface: public ReadWriteArchiveInterface
 {
 	Q_OBJECT
 	public:
@@ -38,12 +38,24 @@ class LibArchiveInterface: public ReadOnlyArchiveInterface
 		~LibArchiveInterface();
 
 		bool list();
-		bool copyFiles( const QList<QVariant> & files, const QString & destinationDirectory, bool preservePaths );
+		bool copyFiles( const QList<QVariant> & files, const QString & destinationDirectory, ExtractionOptions options );
+
+		bool addFiles( const QStringList & files, const CompressionOptions& options );
+		bool deleteFiles( const QList<QVariant> & files );
 
 	private:
 		int extractionFlags() const;
-		void copyData( struct archive *source, struct archive *dest );
+		void copyData( struct archive *source, struct archive *dest, bool partialprogress = true );
+		void copyData( QString filename, struct archive *dest, bool partialprogress = true );
+		void emitEntryFromArchiveEntry(struct archive_entry *entry);
+		bool writeFile(const QString& fileName, struct archive* arch, struct archive_entry* entry);
+
+
 		int cachedArchiveEntryCount;
+		qlonglong extractedFilesSize;
+		qlonglong currentExtractedFilesSize;
+		bool m_emitNoEntries;
+		QStringList m_writtenFiles;
 };
 
 #endif // LIBARCHIVEHANDLER_H
