@@ -109,6 +109,7 @@ class KDE_EXPORT KNumber
 
   KNumber(qint32 num = 0);
   KNumber(quint32 num);  
+  KNumber(qint64 num);
   KNumber(quint64 num);
 
   KNumber(double num);
@@ -215,6 +216,8 @@ class KDE_EXPORT KNumber
    */
   KNumber const cbrt(void) const;
 
+  KNumber const factorial(void) const;
+
   /**
    * Truncates a @p KNumber to its integer type returning a number of
    * type @p NumType::IntegerType.
@@ -241,25 +244,26 @@ class KDE_EXPORT KNumber
   operator bool(void) const;
   operator qint32(void) const;
   operator quint32(void) const;
+  operator qint64(void) const;
   operator quint64(void) const;
   operator double(void) const;
 
-  bool const operator==(KNumber const & arg2) const
+  bool operator==(KNumber const & arg2) const
   { return (compare(arg2) == 0); }
 
-  bool const operator!=(KNumber const & arg2) const
+  bool operator!=(KNumber const & arg2) const
   { return (compare(arg2) != 0); }
 
-  bool const operator>(KNumber const & arg2) const
+  bool operator>(KNumber const & arg2) const
   { return (compare(arg2) > 0); }
 
-  bool const operator<(KNumber const & arg2) const
+  bool operator<(KNumber const & arg2) const
   { return (compare(arg2) < 0); }
 
-  bool const operator>=(KNumber const & arg2) const
+  bool operator>=(KNumber const & arg2) const
   { return (compare(arg2) >= 0); }
 
-  bool const operator<=(KNumber const & arg2) const
+  bool operator<=(KNumber const & arg2) const
   { return (compare(arg2) <= 0); }
 
   KNumber & operator +=(KNumber const &arg);
@@ -270,7 +274,7 @@ class KDE_EXPORT KNumber
 
  private:
   void simplifyRational(void);
-  int const compare(KNumber const & arg2) const;
+  int compare(KNumber const & arg2) const;
   
   _knumber *_num;
   static bool _float_output;
