@@ -1,7 +1,7 @@
 /*
-    
+
     This file is part of the KFloppy program, part of the KDE project
-    
+
     Copyright (C) 1997 Bernd Johannes Wuebben <wuebben@math.cornell.edu>
     Copyright (C) 2004, 2005 Nicolas GOUTTE <goutte@kde.org>
 
@@ -21,101 +21,115 @@
 
 */
 
+#include "floppy.h"
+#include "format.h"
 
-#include <qlayout.h>
-#include <qcheckbox.h>
-#include <qlabel.h>
+#include <QCheckBox>
+#include <QLabel>
 #include <qcursor.h>
 #include <qradiobutton.h>
-#include <qbuttongroup.h>
-#include <qwhatsthis.h>
-
+#include <q3buttongroup.h>
+//Added by qt3to4:
+#include <QVBoxLayout>
+#include <QFrame>
+#include <QHBoxLayout>
+#include <QGridLayout>
+#include <QKeyEvent>
+#include <QCloseEvent>
+#include <QtDBus/QtDBus>
 #include <kconfig.h>
 
 #include <kmessagebox.h>
 #include <kdebug.h>
 #include <khelpmenu.h>
 #include <kpushbutton.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kapplication.h>
-#include <kprogress.h>
+#include <qprogressbar.h>
 #include <klocale.h>
 #include <kcombobox.h>
 #include <klineedit.h>
-#include <dcopref.h>
 #include <kurl.h>
+#include <ktoolinvocation.h>
+#include <kglobal.h>
 
-#include "floppy.h"
-#include "format.h"
-
-FloppyData::FloppyData(QWidget * parent, const char * name)
- : KDialog( parent, name ),
+FloppyData::FloppyData(QWidget * parent)
+ : KDialog( parent ),
 	formatActions(0L), m_canLowLevel(false), m_canZeroOut( false )
 {
-
+	QWidget *widget = new QWidget(this);
+	setMainWidget(widget);
+	setButtons(None);
 	formating = false;
 	//abort = false;
 	blocks = 0;
 
-        QVBoxLayout* ml = new QVBoxLayout( this, 10 );
+        QVBoxLayout* ml = new QVBoxLayout( widget );
+        ml->setSpacing( 10 );
 
-        QHBoxLayout* h1 = new QHBoxLayout( ml );
+        QHBoxLayout* h1 = new QHBoxLayout();
+        ml->addItem( h1 );
 
-        QVBoxLayout* v1 = new QVBoxLayout( h1 );
+        QVBoxLayout* v1 = new QVBoxLayout( );
+        h1->addItem( v1 );
         h1->addSpacing( 5 );
 
-        QGridLayout* g1 = new QGridLayout( v1, 3, 2 );
+        QGridLayout* g1 = new QGridLayout();
+        v1->addItem( g1 );
 
-        deviceComboBox = new KComboBox( false, this, "ComboBox_1" );
-        label1 = new QLabel( deviceComboBox, i18n("Floppy &drive:"), this );
-        g1->addWidget( label1, 0, 0, AlignLeft );
+        deviceComboBox = new KComboBox( false, widget );
+        label1 = new QLabel( i18n("Floppy &drive:"), widget );
+        label1->setBuddy( deviceComboBox );
+        g1->addWidget( label1, 0, 0, Qt::AlignLeft );
         g1->addWidget( deviceComboBox, 0, 1 );
 
         // Make the combo box editable, so that the user can enter a device name
         deviceComboBox->setEditable( true );
-	
-        deviceComboBox->insertItem(i18n("Primary"));
-	deviceComboBox->insertItem(i18n("Secondary"));
+
+        deviceComboBox->addItem(i18nc("Primary floppy drive", "Primary"));
+	deviceComboBox->addItem(i18nc("Secondary floppy drive", "Secondary"));
 
 	const QString deviceWhatsThis = i18n("<qt>Select the floppy drive.</qt>");
-	
-	QWhatsThis::add(label1, deviceWhatsThis);
-	QWhatsThis::add(deviceComboBox, deviceWhatsThis);
 
-        
-        densityComboBox = new KComboBox( false, this, "ComboBox_1" );
-        label2 = new QLabel( densityComboBox, i18n("&Size:"), this);
-        g1->addWidget( label2, 1, 0, AlignLeft );
+	label1->setWhatsThis( deviceWhatsThis);
+	deviceComboBox->setWhatsThis( deviceWhatsThis);
+
+
+        densityComboBox = new KComboBox( false, widget );
+        label2 = new QLabel( i18n("&Size:"), widget);
+        label2->setBuddy( densityComboBox );
+        g1->addWidget( label2, 1, 0, Qt::AlignLeft );
         g1->addWidget( densityComboBox, 1, 1 );
 
 #if defined(ANY_LINUX)
-	densityComboBox->insertItem( i18n( "Auto-Detect" ) );
+	densityComboBox->addItem( i18n( "Auto-Detect" ) );
 #endif
-	densityComboBox->insertItem(i18n("3.5\" 1.44MB"));
-	densityComboBox->insertItem(i18n("3.5\" 720KB"));
-	densityComboBox->insertItem(i18n("5.25\" 1.2MB"));
-	densityComboBox->insertItem(i18n("5.25\" 360KB"));
+	densityComboBox->addItem(i18n("3.5\" 1.44MB"));
+	densityComboBox->addItem(i18n("3.5\" 720KB"));
+	densityComboBox->addItem(i18n("5.25\" 1.2MB"));
+	densityComboBox->addItem(i18n("5.25\" 360KB"));
 
-	const QString densityWhatsThis = 
+	const QString densityWhatsThis =
 	    i18n("<qt>This allows you to select the "
 	         "floppy disk's size and density.</qt>");
-	
-	QWhatsThis::add(label2, densityWhatsThis);
-	QWhatsThis::add(densityComboBox, densityWhatsThis);
+
+	label2->setWhatsThis( densityWhatsThis);
+	densityComboBox->setWhatsThis( densityWhatsThis);
 
 
-        filesystemComboBox = new KComboBox( false, this, "ComboBox_2" );
-        label3 = new QLabel( filesystemComboBox, i18n("F&ile system:"), this);
-        g1->addWidget( label3, 2, 0, AlignLeft );
+        filesystemComboBox = new KComboBox( false, widget );
+        label3 = new QLabel( i18n("F&ile system:"), widget);
+        label3->setBuddy( filesystemComboBox );
+        g1->addWidget( label3, 2, 0, Qt::AlignLeft );
         g1->addWidget( filesystemComboBox, 2, 1 );
-	g1->setColStretch(1, 1);
+	g1->setColumnStretch(1, 1);
 
 #if defined(ANY_LINUX)
-        QWhatsThis::add( label3,
-            i18n( "Linux", "KFloppy supports three file formats under Linux: MS-DOS, Ext2, and Minix" ) );
+        label3->setWhatsThis(
+            i18nc( "Linux", "KFloppy supports three file formats under Linux: MS-DOS, Ext2, and Minix" ) );
 #elif defined(ANY_BSD)
-        QWhatsThis::add( label3,
-            i18n( "BSD", "KFloppy supports three file formats under BSD: MS-DOS, UFS, and Ext2" ) );
+        label3->setWhatsThis(
+            i18nc( "BSD", "KFloppy supports three file formats under BSD: MS-DOS, UFS, and Ext2" ) );
 #endif
         // If you modify the user visible string, change them also (far) below
 
@@ -123,19 +137,19 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
         uint numFileSystems = 0;
 
 #if defined(ANY_LINUX)
-        QWhatsThis::add( filesystemComboBox,
-            i18n( "Linux", "KFloppy supports three file formats under Linux: MS-DOS, Ext2, and Minix" ) );
+        filesystemComboBox->setWhatsThis(
+            i18nc( "Linux", "KFloppy supports three file formats under Linux: MS-DOS, Ext2, and Minix" ) );
         if (FATFilesystem::runtimeCheck()) {
-            filesystemComboBox->insertItem(i18n("DOS"));
+            filesystemComboBox->addItem(i18n("DOS"));
             ++numFileSystems;
-            userFeedBack += i18n( "Linux", "Program mkdosfs found." );
+            userFeedBack += i18nc( "Linux", "Program mkdosfs found." );
         }
         else {
-            userFeedBack += i18n( "Linux", "Program mkdosfs <b>not found</b>. MSDOS formatting <b>not available</b>." );
+            userFeedBack += i18nc( "Linux", "Program mkdosfs <b>not found</b>. MSDOS formatting <b>not available</b>." );
         }
         userFeedBack += "<br>";
         if (Ext2Filesystem::runtimeCheck()) {
-            filesystemComboBox->insertItem(i18n("ext2"));
+            filesystemComboBox->addItem(i18n("ext2"));
             ++numFileSystems;
             userFeedBack += i18n( "Program mke2fs found." );
         }
@@ -144,36 +158,36 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
         }
         userFeedBack += "<br>";
         if (MinixFilesystem::runtimeCheck()) {
-            filesystemComboBox->insertItem(i18n("Minix"));
+            filesystemComboBox->addItem(i18n("Minix"));
             ++numFileSystems;
-            userFeedBack += i18n( "Linux", "Program mkfs.minix found." );
+            userFeedBack += i18nc( "Linux", "Program mkfs.minix found." );
         }
         else {
-            userFeedBack += i18n( "Linux", "Program mkfs.minix <b>not found</b>. Minix formatting <b>not available</b>" );
+            userFeedBack += i18nc( "Linux", "Program mkfs.minix <b>not found</b>. Minix formatting <b>not available</b>" );
         }
 #elif defined(ANY_BSD)
-        QWhatsThis::add( filesystemComboBox,
-            i18n( "BSD", "KFloppy supports two file formats under BSD: MS-DOS and UFS" ) );
+        filesystemComboBox->setWhatsThis(
+            i18nc( "BSD", "KFloppy supports two file formats under BSD: MS-DOS and UFS" ) );
         if (FATFilesystem::runtimeCheck()) {
-            filesystemComboBox->insertItem(i18n("DOS"));
+            filesystemComboBox->addItem(i18n("DOS"));
             ++numFileSystems;
-            userFeedBack += i18n( "BSD", "Program newfs_msdos found." );
+            userFeedBack += i18nc( "BSD", "Program newfs_msdos found." );
         }
         else {
-            userFeedBack += i18n( "BSD", "Program newfs_msdos <b>not found</b>. MSDOS formatting <b>not available</b>." );
+            userFeedBack += i18nc( "BSD", "Program newfs_msdos <b>not found</b>. MSDOS formatting <b>not available</b>." );
         }
         userFeedBack += "<br>";
         if (UFSFilesystem::runtimeCheck()) {
-            filesystemComboBox->insertItem(i18n("UFS"));
+            filesystemComboBox->addItem(i18n("UFS"));
             ++numFileSystems;
-            userFeedBack += i18n( "BSD", "Program newfs found." );
+            userFeedBack += i18nc( "BSD", "Program newfs found." );
         }
         else {
-            userFeedBack += i18n( "BSD", "Program newfs <b>not found</b>. UFS formatting <b>not available</b>." );
+            userFeedBack += i18nc( "BSD", "Program newfs <b>not found</b>. UFS formatting <b>not available</b>." );
         }
         userFeedBack += "<br>";
         if (Ext2Filesystem::runtimeCheck()) {
-            filesystemComboBox->insertItem(i18n("ext2"));
+            filesystemComboBox->addItem(i18n("ext2"));
             ++numFileSystems;
             userFeedBack += i18n( "Program mke2fs found." );
         }
@@ -184,20 +198,26 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 
         v1->addSpacing( 10 );
 
-        buttongroup = new QButtonGroup( 3, Qt::Vertical, i18n("&Formatting"), this, "ButtonGroup_1" );
+        buttongroup = new QGroupBox( i18n("&Formatting"), this );
+        QVBoxLayout* buttonGroupLayout = new QVBoxLayout(buttongroup);
 
-
-        quick = new QRadioButton( i18n( "Q&uick format" ), buttongroup, "RadioButton_2" );
-        QWhatsThis::add( quick,
+        quick = new QRadioButton( i18n( "Q&uick format" ), buttongroup );
+        buttonGroupLayout->addWidget(quick);
+        quick->setObjectName( "RadioButton_2" );
+        quick->setWhatsThis(
             i18n("<qt>Quick format is only a high-level format:"
                 " it creates only a file system.</qt>") );
 
-	zerooutformat = new QRadioButton( i18n( "&Zero out and quick format"), buttongroup, "RadioButton_ZeroOutFormat" );
-        QWhatsThis::add( zerooutformat,
+        zerooutformat = new QRadioButton( i18n( "&Zero out and quick format"), buttongroup );
+        buttonGroupLayout->addWidget(zerooutformat);
+        zerooutformat->setObjectName( "RadioButton_ZeroOutFormat" );
+        zerooutformat->setWhatsThis(
             i18n("<qt>This first erases the floppy by writing zeros and then it creates the file system.</qt>") );
-	
-        fullformat = new QRadioButton( i18n( "Fu&ll format"), buttongroup, "RadioButton_3" );
-        QWhatsThis::add( fullformat,
+
+        fullformat = new QRadioButton( i18n( "Fu&ll format"), buttongroup );
+        buttonGroupLayout->addWidget(fullformat);
+        fullformat->setObjectName( "RadioButton_3" );
+        fullformat->setWhatsThis(
             i18n("Full format is a low-level and high-level format. It erases everything on the disk.") );
 
         v1->addWidget( buttongroup );
@@ -225,85 +245,90 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
             zerooutformat->setDisabled(true);
             userFeedBack += i18n( "Program dd <b>not found</b>. Zeroing-out <b>disabled</b>." );
         }
-        
-	verifylabel = new QCheckBox( this, "CheckBox_Integrity" );
+
+	verifylabel = new QCheckBox( this );
+	verifylabel->setObjectName( "CheckBox_Integrity" );
 	verifylabel->setText(i18n( "&Verify integrity" ));
 	verifylabel->setChecked(true);
-	v1->addWidget( verifylabel, AlignLeft );
-        QWhatsThis::add( verifylabel,
+	v1->addWidget( verifylabel, Qt::AlignLeft );
+        verifylabel->setWhatsThis(
             i18n("<qt>Check this if you want the floppy disk to be checked after formatting."
             " Please note that the floppy will be checked twice if you have selected full formatting.</qt>") );
 
-	labellabel = new QCheckBox( this, "Checkbox_Label" );
+	labellabel = new QCheckBox( this );
+	labellabel->setObjectName( "Checkbox_Label" );
 	labellabel->setText(i18n( "Volume la&bel:") );
 	labellabel->setChecked(true);
-        v1->addWidget( labellabel, AlignLeft );
-        QWhatsThis::add( labellabel,
+        v1->addWidget( labellabel, Qt::AlignLeft );
+        labellabel->setWhatsThis(
             i18n("<qt>Check this if you want a volume label for your floppy."
             " Please note that Minix does not support labels at all.</qt>") );
 
-        QHBoxLayout* h2 = new QHBoxLayout( v1 );
+        QHBoxLayout* h2 = new QHBoxLayout();
+        v1->addItem( h2 );
         h2->addSpacing( 20 );
 
-	lineedit = new KLineEdit( this, "Lineedit" );
+	lineedit = new KLineEdit( widget );
         // ### TODO ext2 supports 16 characters. Minix has not any label. UFS?
-	lineedit->setText(i18n( "Volume label, maximal 11 characters", "KDE Floppy" ) );
+	lineedit->setText(i18nc( "Volume label, maximal 11 characters", "KDE Floppy" ) );
 	lineedit->setMaxLength(11);
-        h2->addWidget( lineedit, AlignRight );
-        QWhatsThis::add( lineedit,
+        h2->addWidget( lineedit, Qt::AlignRight );
+        lineedit->setWhatsThis(
             i18n("<qt>This is for the volume label."
             " Due to a limitation of MS-DOS the label can only be 11 characters long."
             " Please note that Minix does not support labels, whatever you enter here.</qt>") );
 
 	connect(labellabel,SIGNAL(toggled(bool)),lineedit,SLOT(setEnabled(bool)));
 
-	QVBoxLayout* v3 = new QVBoxLayout( h1 );
+	QVBoxLayout* v3 = new QVBoxLayout();
+        h1->addItem( v3 );
 
-	formatbutton = new KPushButton( this, "PushButton_3" );
+	formatbutton = new KPushButton( widget );
 	formatbutton->setText(i18n( "&Format") );
 	formatbutton->setAutoRepeat( false );
         if (!numFileSystems)
             formatbutton->setDisabled(false); // We have not any helper program for creating any file system
 	connect(formatbutton,SIGNAL(clicked()),this,SLOT(format()));
         v3->addWidget( formatbutton );
-        QWhatsThis::add( formatbutton,
+        formatbutton->setWhatsThis(
             i18n("<qt>Click here to start formatting.</qt>") );
 
         v3->addStretch( 1 );
 
 	//Setup the Help Menu
-	helpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData(), false);
+	helpMenu = new KHelpMenu(this, KGlobal::mainComponent().aboutData(), false);
 
-	helpbutton = new KPushButton( KStdGuiItem::help(), this );
+	helpbutton = new KPushButton( KStandardGuiItem::help(), widget );
 	helpbutton->setAutoRepeat( false );
-	helpbutton->setPopup(helpMenu->menu());
+	helpbutton->setMenu(helpMenu->menu());
 	v3->addWidget( helpbutton );
 
-	quitbutton = new KPushButton( KStdGuiItem::quit(), this );
+	quitbutton = new KPushButton( KStandardGuiItem::quit(), widget );
 	quitbutton->setAutoRepeat( false );
 	connect(quitbutton,SIGNAL(clicked()),this,SLOT(quit()));
 	 v3->addWidget( quitbutton );
 
         ml->addSpacing( 10 );
 
-	frame = new QLabel( this, "NewsWindow" );
+	frame = new QLabel( widget );
+        frame->setObjectName( "NewsWindow" );
 	frame->setFrameStyle(QFrame::Panel | QFrame::Sunken);
-	frame->setAlignment(WordBreak|ExpandTabs);
-        QWhatsThis::add( frame,
+        frame->setWordWrap( true );
+        frame->setWhatsThis(
             i18n("<qt>This is the status window, where error messages are displayed.</qt>") );
 
         QString frameText( userFeedBack );
         frameText.prepend( "<qt>" );
         frameText.append( "</qt>" );
         frame->setText( frameText );
-        
+
         ml->addWidget( frame );
 
-	progress = new KProgress( this, "Progress" );
+	progress = new QProgressBar( widget );
         progress->setDisabled( true );
         ml->addWidget( progress );
 
-	QWhatsThis::add(progress,
+	progress->setWhatsThis(
 			i18n("<qt>Shows progress of the format.</qt>"));
 
 	readSettings();
@@ -312,7 +337,7 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
     if (!numFileSystems) {
         QString errorMessage;
         errorMessage += "<qt>";
-        errorMessage += i18n("KFloppy cannot find any of the needed programs for creating file systems; please check your installation.<br><br>Log:");
+        errorMessage += i18n("KFloppy cannot find any of the needed programs for creating file systems; please check your installation.<br /><br />Log:");
         errorMessage += "<br>";
         errorMessage += userFeedBack;
         errorMessage += "</qt>";
@@ -335,7 +360,7 @@ void FloppyData::keyPressEvent(QKeyEvent *e)
 {
 	switch(e->key()) {
 	case Qt::Key_F1:
-		kapp->invokeHelp();
+		KToolInvocation::invokeHelp();
 		break;
 	default:
 		KDialog::keyPressEvent(e);
@@ -353,11 +378,11 @@ bool FloppyData::findDevice()
     // Note: this function does not handle user-given devices
 
   drive=-1;
-  if( deviceComboBox->currentText() == i18n("Primary") )
+  if( deviceComboBox->currentText() == i18nc("Primary floppy drive", "Primary") )
   {
     drive=0;
   }
-  else if( deviceComboBox->currentText() == i18n("Secondary") )
+  else if( deviceComboBox->currentText() == i18nc("Secondary floppy drive", "Secondary") )
   {
     drive=1;
   }
@@ -393,14 +418,14 @@ bool FloppyData::setInitialDevice(const QString& dev)
 
   QString newDevice = dev;
 
-  KURL url( newDevice );
+  KUrl url( newDevice );
   if( url.isValid() && ( url.protocol() == "media" || url.protocol() == "system" ) ) {
     QString name = url.fileName();
 
-    DCOPRef mediamanager( "kded", "mediamanager" );
-    DCOPReply reply = mediamanager.call("properties(QString)", name);
+    QDBusInterface mediamanager( "org.kde.kded", "/modules/mediamanager", "org.kde.MediaManager" );
+    QDBusReply<QStringList> reply = mediamanager.call( "properties", name );
     if (!reply.isValid()) {
-      kdError() << "Invalid reply from mediamanager" << endl;
+      kError() << "Invalid reply from mediamanager" << endl;
     } else {
       QStringList properties = reply;
       newDevice = properties[5];
@@ -414,10 +439,10 @@ bool FloppyData::setInitialDevice(const QString& dev)
     drive = 1;
 
   // ### TODO user given devices
-    
+
   bool ok = (drive>=0);
   if (ok)
-    deviceComboBox->setCurrentItem(drive);
+    deviceComboBox->setCurrentIndex(drive);
   return ok;
 }
 
@@ -433,7 +458,7 @@ void FloppyData::setEnabled(bool b)
   if (b)
 	unsetCursor();
   else
-	setCursor(QCursor(WaitCursor));
+	setCursor(QCursor(Qt::WaitCursor));
   label1->setEnabled(b);
   deviceComboBox->setEnabled(b);
   label2->setEnabled(b);
@@ -487,17 +512,17 @@ void FloppyData::format(){
 #ifdef ANY_BSD
     if ( userDevice && filesystemComboBox->currentText() != i18n("UFS"))
     {
-        KMessageBox::error( this, i18n("BSD", "Formatting with BSD on a user-given device is only possible with UFS") );
+        KMessageBox::error( this, i18nc("BSD", "Formatting with BSD on a user-given device is only possible with UFS") );
         return;
     }
     // no "else" !
-#endif    
-    if ( userDevice && ( quick->isChecked() || zerooutformat->isChecked() ) ) 
+#endif
+    if ( userDevice && ( quick->isChecked() || zerooutformat->isChecked() ) )
     {
         if (KMessageBox::warningContinueCancel( this,
             i18n("<qt>Formatting will erase all data on the device:<br/><b>%1</b><br/>"
                 "(Please check the correctness of the device name.)<br/>"
-                "Are you sure you wish to proceed?</qt>").arg( currentComboBoxDevice )
+                "Are you sure you wish to proceed?</qt>", currentComboBoxDevice )
                 , i18n("Proceed?") ) != KMessageBox::Continue)
             {
                 return;
@@ -506,7 +531,7 @@ void FloppyData::format(){
     else if ( userDevice )
     {
         // The user has selected full formatting on a user-given device. That is not supported yet!
-        KMessageBox::error( this, "Full formatting of a user-given device is not possible!" );
+        KMessageBox::error( this, i18n("Full formatting of a user-given device is not possible!") );
         return;
     }
     else
@@ -524,7 +549,7 @@ void FloppyData::format(){
   setEnabled(false);
 
         // Erase text box
-        frame->setText( QString::null );
+        frame->setText( QString::null );	//krazy:exclude=nullstrassign for old broken gcc
 
     if ( !userDevice )
     {
@@ -637,14 +662,12 @@ void FloppyData::format(){
 	}
 #endif
 
-
-
 	formatActions->exec();
 }
 
 void FloppyData::formatStatus(const QString &s,int p)
 {
-    kdDebug(2002) << "FloppyData::formatStatus: " << s << " : "  << p << endl;
+    kDebug(2002) << "FloppyData::formatStatus: " << s << " : "  << p ;
 	if (!s.isEmpty())
         {
             const QString oldText ( frame->text() );
@@ -664,51 +687,47 @@ void FloppyData::formatStatus(const QString &s,int p)
 
 void FloppyData::writeSettings(){
 
-        config = kapp->config();
-	config->setGroup("GeneralData");
+        KConfigGroup config = KGlobal::config()->group("GeneralData");
 
-	densityconfig = densityComboBox->currentText().stripWhiteSpace();
-	filesystemconfig = filesystemComboBox->currentText().stripWhiteSpace();
-	driveconfig = deviceComboBox->currentText().stripWhiteSpace();
+	densityconfig = densityComboBox->currentText().trimmed();
+	filesystemconfig = filesystemComboBox->currentText().trimmed();
+	driveconfig = deviceComboBox->currentText().trimmed();
 
 	quickformatconfig = quick->isChecked();
 
-	labelnameconfig = lineedit->text().stripWhiteSpace();
+	labelnameconfig = lineedit->text().trimmed();
 
 	labelconfig = labellabel->isChecked();
 
 	verifyconfig = verifylabel->isChecked();
 
-	config->writeEntry("CreateLabel",labelconfig);
-	config->writeEntry("Label",labelnameconfig);
+	config.writeEntry("CreateLabel",labelconfig);
+	config.writeEntry("Label",labelnameconfig);
 
 
-	config->writeEntry("QuickFormat",quickformatconfig);
-	config->writeEntry("FloppyDrive",driveconfig);
-	config->writeEntry("Density",densityconfig);
-	config->writeEntry("Filesystem",filesystemconfig);
-	config->writeEntry("Verify",verifyconfig);
-	config->sync();
-
+	config.writeEntry("QuickFormat",quickformatconfig);
+	config.writeEntry("FloppyDrive",driveconfig);
+	config.writeEntry("Density",densityconfig);
+	config.writeEntry("Filesystem",filesystemconfig);
+	config.writeEntry("Verify",verifyconfig);
+	config.sync();
 }
 
 void FloppyData::readSettings(){
 
-        config = kapp->config();
-	config->setGroup("GeneralData");
+        KConfigGroup config = KGlobal::config()->group("GeneralData");
 
-	verifyconfig = config->readNumEntry("Verify", 1);
-	labelconfig = config->readNumEntry("CreateLabel",1);
-	labelnameconfig = config->readEntry( "Label", i18n("Volume label, maximal 11 characters", "KDE Floppy") );
-	quickformatconfig = config->readNumEntry("QuickFormat",0);
-	driveconfig = config->readEntry( "FloppyDrive", i18n("Primary") );
+	verifyconfig = config.readEntry("Verify", 1);
+	labelconfig = config.readEntry("CreateLabel",1);
+	labelnameconfig = config.readEntry( "Label", i18nc("Volume label, maximal 11 characters", "KDE Floppy") );
+	quickformatconfig = config.readEntry("QuickFormat",0);
+	driveconfig = config.readEntry( "FloppyDrive", i18nc("Primary floppy drive", "Primary") );
 #if defined(ANY_LINUX)
-	densityconfig = config->readEntry( "Density", i18n( "Auto-Detect" ) );
+	densityconfig = config.readEntry( "Density", i18n( "Auto-Detect" ) );
 #else
-	densityconfig = config->readEntry( "Density", i18n("3.5\" 1.44MB") );
+	densityconfig = config.readEntry( "Density", i18n("3.5\" 1.44MB") );
 #endif
-	filesystemconfig = config->readEntry( "Filesystem", i18n("DOS") );
-
+	filesystemconfig = config.readEntry( "Filesystem", i18n("DOS") );
 }
 
 void FloppyData::setWidgets(){
@@ -720,20 +739,20 @@ void FloppyData::setWidgets(){
   lineedit->setText(labelnameconfig);
 
   for(int i = 0 ; i < deviceComboBox->count(); i++){
-    if ( deviceComboBox->text(i) == driveconfig){
-      deviceComboBox->setCurrentItem(i);
+    if ( deviceComboBox->itemText(i) == driveconfig){
+      deviceComboBox->setCurrentIndex(i);
     }
   }
 
   for(int i = 0 ; i < filesystemComboBox->count(); i++){
-    if ( filesystemComboBox->text(i) == filesystemconfig){
-      filesystemComboBox->setCurrentItem(i);
+    if ( filesystemComboBox->itemText(i) == filesystemconfig){
+      filesystemComboBox->setCurrentIndex(i);
     }
   }
 
   for(int i = 0 ; i < densityComboBox->count(); i++){
-    if ( densityComboBox->text(i) == densityconfig){
-      densityComboBox->setCurrentItem(i);
+    if ( densityComboBox->itemText(i) == densityconfig){
+      densityComboBox->setCurrentIndex(i);
     }
   }
 }
