@@ -1,7 +1,7 @@
 /*
 
     This file is part of the KFloppy program, part of the KDE project
-    
+
     Copyright (C) 2002 Adriaan de Groot <groot@kde.org>
     Copyright (C) 2004, 2005 Nicolas GOUTTE <goutte@kde.org>
 
@@ -20,21 +20,20 @@
 
 */
 
+#include "format.h"
 
 #include <unistd.h>
 #include <stdlib.h>
 
-#include <qtimer.h>
-#include <qregexp.h>
+#include <QTimer>
+#include <QRegExp>
 
 #include <klocale.h>
-#include <kprocess.h>
+#include <k3process.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
 
-#include "format.h"
-
-static QString extPath = QString::null;
+static QString extPath = QString();
 
 /* static */ QString findExecutable(const QString &e)
 {
@@ -50,7 +49,6 @@ static QString extPath = QString::null;
 }
 
 
-
 KFAction::KFAction(QObject *parent) :
 	QObject(parent)
 {
@@ -76,7 +74,7 @@ KFAction::~KFAction()
 class KFActionQueue_p
 {
 public:
-	QPtrList<KFAction> list;
+	QList<KFAction*> list;
 } ;
 
 KFActionQueue::KFActionQueue(QObject *parent) :
@@ -84,12 +82,13 @@ KFActionQueue::KFActionQueue(QObject *parent) :
 	d(new KFActionQueue_p)
 {
 	DEBUGSETUP;
-	d->list.setAutoDelete(true);
 }
 
 KFActionQueue::~KFActionQueue()
 {
 	DEBUGSETUP;
+	qDeleteAll(d->list);
+	d->list.clear();
 	delete d;
 }
 
@@ -98,7 +97,7 @@ void KFActionQueue::queue(KFAction *p)
 	DEBUGSETUP;
 
 	d->list.append(p);
-	DEBUGS(p->name());
+	DEBUGS(p->objectName());
 }
 
 /* virtual */ void KFActionQueue::exec()
@@ -145,7 +144,7 @@ void KFActionQueue::queue(KFAction *p)
 	}
 	else
 	{
-		kdDebug(KFAREA) << "Running action " << next->name() << endl;
+		kDebug(KFAREA) << "Running action " << next->objectName() ;
 		QObject::connect(next,SIGNAL(done(KFAction *,bool)),
 			this,SLOT(actionDone(KFAction *,bool)));
 		// Propagate signals
@@ -156,8 +155,6 @@ void KFActionQueue::queue(KFAction *p)
 }
 
 
-
-
 // Here we have names of devices. The variable
 // names are basically the linux device names,
 // replace with whatever your OS needs instead.
@@ -165,15 +162,15 @@ void KFActionQueue::queue(KFAction *p)
 //
 #ifdef ANY_LINUX
 
-const char *fd0H1440[] = { "/dev/fd0u1440", "/dev/floppy/0u1440", "/dev/fd0h1440", "/dev/fd0H1440", "/dev/fd0", 0L } ;
-const char *fd0D720[] = { "/dev/fd0u720", "/dev/floppy/0u720", "/dev/fd0D720", "/dev/fd0h720", "/dev/fd0", 0L };
-const char *fd0h1200[] = { "/dev/fd0h1200", "/dev/floppy/0h1200", "/dev/fd0", 0L };
-const char *fd0h360[] = { "/dev/fd0u360", "/dev/floppy/0u360", "/dev/fd0h360", "/dev/fd0d360", "/dev/fd0", 0L };
+const char *fd0H1440[] = { "/dev/fd0u1440", "/dev/floppy/0u1440", "/dev/fd0h1440", "/dev/fd0H1440", 0L } ;
+const char *fd0D720[] = { "/dev/fd0u720", "/dev/floppy/0u720", "/dev/fd0D720", "/dev/fd0h720", 0L };
+const char *fd0h1200[] = { "/dev/fd0h1200", "/dev/floppy/0h1200", 0L };
+const char *fd0h360[] = { "/dev/fd0u360", "/dev/floppy/0u360", "/dev/fd0h360", "/dev/fd0d360", 0L };
 
-const char *fd1H1440[] = { "/dev/fd1u1440", "/dev/floppy/1u1440","/dev/fd1h1440", "/dev/fd1H1440", "/dev/fd1", 0L } ;
-const char *fd1D720[] = { "/dev/fd1u720", "/dev/floppy/1u720", "/dev/fd1D720", "/dev/fd1h720", "/dev/fd1", 0L };
-const char *fd1h1200[] = { "/dev/fd1h1200", "/dev/floppy/1h1200", "/dev/fd1", 0L };
-const char *fd1h360[] = { "/dev/fd1u360", "/dev/floppy/1u360","/dev/fd1h360", "/dev/fd1d360", "/dev/fd1", 0L };
+const char *fd1H1440[] = { "/dev/fd1u1440", "/dev/floppy/1u1440","/dev/fd1h1440", "/dev/fd1H1440", 0L } ;
+const char *fd1D720[] = { "/dev/fd1u720", "/dev/floppy/1u720", "/dev/fd1D720", "/dev/fd1h720", 0L };
+const char *fd1h1200[] = { "/dev/fd1h1200", "/dev/floppy/1h1200", 0L };
+const char *fd1h360[] = { "/dev/fd1u360", "/dev/floppy/1u360","/dev/fd1h360", "/dev/fd1d360", 0L };
 
 const char *fd0auto[] = { "/dev/fd0", 0L };
 const char *fd1auto[] = { "/dev/fd1", 0L };
@@ -193,7 +190,7 @@ const char *fd1[] = { "/dev/fd1", 0L } ;
 //
 //
 // Note that the data originally contained in KFloppy was
-// patently false, so most of this is fake. I guess noone ever
+// patently false, so most of this is fake. I guess no one ever
 // formatted a 5.25" floppy.
 //
 // The flags field is unused in this implementation.
@@ -262,11 +259,11 @@ bool FloppyAction::configureDevice(int drive,int density)
 	const char *devicename = 0L;
 
 	deviceInfo=0L;
-	deviceName = QString::null;
+	deviceName = QString();
 
 	if ((drive<0) || (drive>1))
 	{
-		emit status(i18n("Unexpected drive number %1.").arg(drive),-1);
+		emit status(i18n("Unexpected drive number %1.", drive),-1);
 		return false;
 	}
 
@@ -278,7 +275,7 @@ bool FloppyAction::configureDevice(int drive,int density)
         }
 	if (!deviceinfo)
 	{
-		emit status(i18n("Unexpected density number %1.").arg(density),-1);
+		emit status(i18n("Unexpected density number %1.", density),-1);
 		return false;
 	}
 
@@ -293,8 +290,8 @@ bool FloppyAction::configureDevice(int drive,int density)
 
 	if (!deviceinfo || !deviceinfo->devices)
 	{
-		emit status(i18n("Cannot find a device for drive %1 and density %2.")
-			.arg(drive).arg(density),-1);
+		emit status(i18n("Cannot find a device for drive %1 and density %2.",
+			 drive, density),-1);
 		return false;
 	}
 
@@ -303,7 +300,7 @@ bool FloppyAction::configureDevice(int drive,int density)
 	{
 		if (access(*devices,W_OK)>=0)
 		{
-			kdDebug(KFAREA) << "Found device " << *devices << endl;
+			kDebug(KFAREA) << "Found device " << *devices ;
 			devicename=*devices;
 			break;
 		}
@@ -313,7 +310,7 @@ bool FloppyAction::configureDevice(int drive,int density)
 	{
 		const QString str = i18n(
 			"Cannot access %1\nMake sure that the device exists and that "
-			"you have write permission to it.").arg(deviceinfo->devices[0]);
+			"you have write permission to it.", deviceinfo->devices[0]);
 		emit status(str,-1);
 		return false;
 	}
@@ -324,7 +321,7 @@ bool FloppyAction::configureDevice(int drive,int density)
 	return true;
 }
 
-void FloppyAction::processDone(KProcess *p)
+void FloppyAction::processDone(K3Process *p)
 {
 	DEBUGSETUP;
 
@@ -338,30 +335,30 @@ void FloppyAction::processDone(KProcess *p)
 	{
 	        if (p->exitStatus() == 0)
 	        {
-			emit status(QString::null,100);
+			emit status(QString::null,100);	//krazy:exclude=nullstrassign for old broken gcc
 			emit done(this,true);
 		}
 		else
 		{
-			emit status(i18n("The program %1 terminated with an error.").arg(theProcessName),100);
+			emit status(i18n("The program %1 terminated with an error.", theProcessName),100);
 			emit done(this,false);
 		}
 	}
 	else
 	{
-		emit status(i18n("The program %1 terminated abnormally.").arg(theProcessName),100);
+		emit status(i18n("The program %1 terminated abnormally.", theProcessName),100);
 		emit done(this,false);
 	}
 }
 
-void FloppyAction::processStdOut(KProcess *, char *b, int l)
+void FloppyAction::processStdOut(K3Process *, char *b, int l)
 {
 	Q_UNUSED(b);
 	Q_UNUSED(l);
-	kdDebug(KFAREA) << "stdout:" << QString::fromLatin1(b,l) << endl;
+	kDebug(KFAREA) << "stdout:" << QString::fromLatin1(b,l) ;
 }
 
-void FloppyAction::processStdErr(KProcess *p, char *b, int l)
+void FloppyAction::processStdErr(K3Process *p, char *b, int l)
 {
 	processStdOut(p,b,l);
 }
@@ -370,20 +367,20 @@ bool FloppyAction::startProcess()
 {
 	DEBUGSETUP;
 
-	connect(theProcess,SIGNAL(processExited(KProcess *)),
-		this,SLOT(processDone(KProcess *)));
-	connect(theProcess,SIGNAL(receivedStdout(KProcess *,char *,int)),
-		this,SLOT(processStdOut(KProcess *,char *,int)));
-	connect(theProcess,SIGNAL(receivedStderr(KProcess *,char *,int)),
-		this,SLOT(processStdErr(KProcess *,char *,int)));
+	connect(theProcess,SIGNAL(processExited(K3Process *)),
+		this,SLOT(processDone(K3Process *)));
+	connect(theProcess,SIGNAL(receivedStdout(K3Process *,char *,int)),
+		this,SLOT(processStdOut(K3Process *,char *,int)));
+	connect(theProcess,SIGNAL(receivedStderr(K3Process *,char *,int)),
+		this,SLOT(processStdErr(K3Process *,char *,int)));
 
         theProcess->setEnvironment( "LC_ALL", "C" ); // We need the untranslated output of the tool
-	return theProcess->start(KProcess::NotifyOnExit,
-		KProcess::AllOutput);
+	return theProcess->start(K3Process::NotifyOnExit,
+		K3Process::AllOutput);
 }
 
 
-/* static */ QString FDFormat::fdformatName = QString::null;
+/* static */ QString FDFormat::fdformatName = QString();
 
 FDFormat::FDFormat(QObject *p) :
 	FloppyAction(p),
@@ -391,7 +388,7 @@ FDFormat::FDFormat(QObject *p) :
 {
 	DEBUGSETUP;
 	theProcessName = QString::fromLatin1("fdformat");
-	setName("FDFormat");
+	setObjectName("FDFormat");
 }
 
 /* static */ bool FDFormat::runtimeCheck()
@@ -425,7 +422,7 @@ bool FDFormat::configure(bool v)
 	}
 
 	if (theProcess) delete theProcess;
-	theProcess = new KProcess;
+	theProcess = new K3Process;
 
 	formatTrackCount=0;
 
@@ -464,7 +461,7 @@ bool FDFormat::configure(bool v)
 // need, since the messages can be standardized across OSsen.
 //
 //
-void FDFormat::processStdOut(KProcess *, char *b, int l)
+void FDFormat::processStdOut(K3Process *, char *b, int l)
 {
 	DEBUGSETUP;
 	QString s;
@@ -473,12 +470,12 @@ void FDFormat::processStdOut(KProcess *, char *b, int l)
 	if (b[0]=='F')
 	{
 		formatTrackCount++;
-		emit status(QString::null,
+		emit status(QString::null,	//krazy:exclude=nullstrassign for old broken gcc
 			formatTrackCount * 100 / deviceInfo->tracks);
 	}
 	else if (b[0]=='E')
 	{
-		emit status(i18n("Error formatting track %1.").arg(formatTrackCount),-1);
+		emit status(i18n("Error formatting track %1.", formatTrackCount),-1);
 	}
 	else
 	{
@@ -491,7 +488,7 @@ void FDFormat::processStdOut(KProcess *, char *b, int l)
                             "have selected a valid floppy drive."),-1);
                     return;
 		}
-		if (s.find("/dev/")>=0)
+		if (s.indexOf("/dev/")>=0)
 		{
 			emit status(s,-1);
 			return;
@@ -502,21 +499,21 @@ void FDFormat::processStdOut(KProcess *, char *b, int l)
 	s = QString::fromLatin1(b,l);
 	DEBUGS(s);
         QRegExp regexp( "([0-9]+)" );
-        if ( s.startsWith( "bad data at cyl" ) || ( s.find( "Problem reading cylinder" ) != -1 ) )
+        if ( s.startsWith( "bad data at cyl" ) || s.contains( "Problem reading cylinder" ) )
         {
-            if ( regexp.search( s ) > -1 )
+            if ( regexp.indexIn( s ) > -1 )
             {
                 const int track = regexp.cap(1).toInt();
-                emit status(i18n("Low-level formatting error at track %1.").arg(track), -1);
+                emit status(i18n("Low-level formatting error at track %1.", track), -1);
             }
             else
             {
                 // This error should not happen
-                emit status(i18n("Low-level formatting error: %1").arg(s), -1);
+                emit status(i18n("Low-level formatting error: %1", s), -1);
             }
             return;
         }
-	else if (s.find("ioctl(FDFMTBEG)")!=-1)
+	else if (s.contains("ioctl(FDFMTBEG)"))
 	{
             emit status (i18n(
                     "Cannot access floppy or floppy drive.\n"
@@ -524,25 +521,25 @@ void FDFormat::processStdOut(KProcess *, char *b, int l)
                     "have selected a valid floppy drive."),-1);
             return;
 	}
-        else if (s.find("busy")!=-1) // "Device or resource busy"
+        else if (s.contains("busy")) // "Device or resource busy"
         {
             emit status(i18n("Device busy.\nPerhaps you need to unmount the floppy first."),-1);
             return;
         }
         // Be careful to leave "iotcl" as last before checking numbers
-        else if (s.find("ioctl")!=-1)
+        else if (s.contains("ioctl"))
         {
-            emit status(i18n("Low-level format error: %1").arg(s),-1);
+            emit status(i18n("Low-level format error: %1", s),-1);
             return;
         }
         // Check for numbers at last (as /dev/fd0u1440 has numbers too)
-        else if ( regexp.search(s) > -1 )
+        else if ( regexp.indexIn(s) > -1 )
         {
             // Normal track number (formatting or verifying)
             const int p = regexp.cap(1).toInt();
             if ((p>=0) && (p<deviceInfo->tracks))
             {
-                    emit status(QString::null,
+                    emit status(QString::null,	//krazy:exclude=nullstrassign for old broken gcc
                             p * 100 / deviceInfo->tracks);
             }
         }
@@ -551,14 +548,14 @@ void FDFormat::processStdOut(KProcess *, char *b, int l)
 }
 
 
-/* static */ QString DDZeroOut::m_ddName = QString::null;
+/* static */ QString DDZeroOut::m_ddName = QString();
 
 DDZeroOut::DDZeroOut(QObject *p) :
     FloppyAction(p)
 {
-    kdDebug(KFAREA) << (__PRETTY_FUNCTION__) << endl;
+    kDebug(KFAREA) << k_funcinfo ;
     theProcessName = QString::fromLatin1("dd");
-    setName("DD");
+    setObjectName("DD");
 }
 
 /* static */ bool DDZeroOut::runtimeCheck()
@@ -569,7 +566,7 @@ DDZeroOut::DDZeroOut(QObject *p) :
 
 /* virtual */ void DDZeroOut::exec()
 {
-    kdDebug(KFAREA) << (__PRETTY_FUNCTION__) << endl;
+    kDebug(KFAREA) << k_funcinfo ;
 
     if ( deviceName.isEmpty() )
     {
@@ -586,7 +583,7 @@ DDZeroOut::DDZeroOut(QObject *p) :
     }
 
     delete theProcess;
-    theProcess = new KProcess;
+    theProcess = new K3Process;
 
     *theProcess << m_ddName ;
 
@@ -601,13 +598,13 @@ DDZeroOut::DDZeroOut(QObject *p) :
 
 }
 
-void DDZeroOut::processDone(KProcess *p)
+void DDZeroOut::processDone(K3Process *p)
 {
-    kdDebug(KFAREA) << (__PRETTY_FUNCTION__) << endl;
+    kDebug(KFAREA) << k_funcinfo ;
 
     if (p!=theProcess)
     {
-            kdDebug(KFAREA) << "Strange process exited." << endl;
+            kDebug(KFAREA) << "Strange process exited." ;
             return;
     }
 
@@ -617,13 +614,12 @@ void DDZeroOut::processDone(KProcess *p)
      *
      * ### TODO: really check if the exit is not on an other error and then abort the formatting
      */
-    emit status(QString::null,100);
+    emit status(QString::null,100);	//krazy:exclude=nullstrassign for old broken gcc
     emit done(this,true);
 }
 
 
-
-/* static */ QString FATFilesystem::newfs_fat = QString::null ;
+/* static */ QString FATFilesystem::newfs_fat = QString();
 
 FATFilesystem::FATFilesystem(QObject *parent) :
 	FloppyAction(parent)
@@ -631,7 +627,7 @@ FATFilesystem::FATFilesystem(QObject *parent) :
 	DEBUGSETUP;
 	runtimeCheck();
 	theProcessName=newfs_fat;
-	setName("FATFilesystem");
+	setObjectName("FATFilesystem");
 }
 
 /* static */ bool FATFilesystem::runtimeCheck()
@@ -654,9 +650,9 @@ bool FATFilesystem::configure(bool v,bool l,const QString &lbl)
 	doVerify=v;
 	doLabel=l;
 	if (l)
-		label=lbl.simplifyWhiteSpace();
+		label=lbl.simplified();
 	else
-		label=QString::null;
+		label.clear();
 
 	return true;
 }
@@ -665,7 +661,6 @@ void FATFilesystem::exec()
 {
 	DEBUGSETUP;
 
-        
 	if (
 #ifdef ANY_BSD // BSD needs the deviceInfo for the block count
             !deviceInfo ||
@@ -685,7 +680,7 @@ void FATFilesystem::exec()
 	}
 
 	if (theProcess) delete theProcess;
-	KProcess *p = theProcess = new KProcess;
+	K3Process *p = theProcess = new K3Process;
 
 	*p << newfs_fat;
 #ifdef ANY_BSD
@@ -715,19 +710,19 @@ void FATFilesystem::exec()
 	}
 }
 
-void FATFilesystem::processStdOut(KProcess *, char *b, int l)
+void FATFilesystem::processStdOut(K3Process *, char *b, int l)
 {
 #ifdef ANY_BSD
     // ### TODO: do some checks
 #elif defined(ANY_LINUX)
     QString s ( QString::fromLatin1( b, l ) );
-    kdDebug(KFAREA) << s << endl;
-    if (s.find("mounted file system")!=-1) // "/dev/fd0 contains a mounted file system
+    kDebug(KFAREA) << s ;
+    if (s.contains("mounted file system")) // "/dev/fd0 contains a mounted file system
     {
         emit status(i18n("Floppy is mounted.\nYou need to unmount the floppy first."),-1);
         return;
     }
-    else if (s.find("busy")!=-1) // "Device or resource busy"
+    else if (s.contains("busy")) // "Device or resource busy"
     {
         emit status(i18n("Device busy.\nPerhaps you need to unmount the floppy first."),-1);
         return;
@@ -743,11 +738,9 @@ void FATFilesystem::processStdOut(KProcess *, char *b, int l)
 }
 
 
-
-
 #ifdef ANY_BSD
 
-/* static */ QString UFSFilesystem::newfs = QString::null ;
+/* static */ QString UFSFilesystem::newfs = QString();
 
 UFSFilesystem::UFSFilesystem(QObject *parent) :
 	FloppyAction(parent)
@@ -755,7 +748,7 @@ UFSFilesystem::UFSFilesystem(QObject *parent) :
 	DEBUGSETUP;
 	runtimeCheck();
 	theProcessName=newfs;
-	setName("UFSFilesystem");
+	setObjectName("UFSFilesystem");
 }
 
 /* static */ bool UFSFilesystem::runtimeCheck()
@@ -780,16 +773,16 @@ void UFSFilesystem::exec()
 
 	if (newfs.isEmpty())
 	{
-		emit status(i18n("BSD", "Cannot find a program to create UFS filesystems."),-1);
+		emit status(i18nc("BSD", "Cannot find a program to create UFS filesystems."),-1);
 		emit done(this,false);
 		return;
 	}
 
 	if (theProcess) delete theProcess;
-	KProcess *p = theProcess = new KProcess;
+	K3Process *p = theProcess = new K3Process;
 
 	*p << newfs;
-        
+
         // ### TODO: is it still needed? (FreeBSD 5.3's man page says: "For backward compatibility.")
         if ( deviceInfo )
            *p << "-T" << QString("fd%1").arg(deviceInfo->blocks);
@@ -798,15 +791,14 @@ void UFSFilesystem::exec()
 
 	if (!startProcess())
 	{
-		emit status(i18n("BSD", "Cannot start UFS format program."),-1);
+		emit status(i18nc("BSD", "Cannot start UFS format program."),-1);
 		emit done(this,false);
 	}
 }
 #endif
 
 
-
-/* static */ QString Ext2Filesystem::newfs = QString::null ;
+/* static */ QString Ext2Filesystem::newfs = QString();
 
 Ext2Filesystem::Ext2Filesystem(QObject *parent) :
 	FloppyAction(parent)
@@ -814,7 +806,7 @@ Ext2Filesystem::Ext2Filesystem(QObject *parent) :
 	DEBUGSETUP;
 	runtimeCheck();
 	theProcessName="mke2fs";
-	setName("Ext2Filesystem");
+	setObjectName("Ext2Filesystem");
 }
 
 /* static */ bool Ext2Filesystem::runtimeCheck()
@@ -832,11 +824,11 @@ bool Ext2Filesystem::configure(bool v,bool l,const QString &lbl)
 	doLabel=l;
 	if (l)
 	{
-		label=lbl.stripWhiteSpace();
+		label=lbl.trimmed();
 	}
 	else
 	{
-		label=QString::null;
+		label.clear();
 	}
 
 	return true;
@@ -865,7 +857,7 @@ void Ext2Filesystem::exec()
 	}
 
 	if (theProcess) delete theProcess;
-	KProcess *p = theProcess = new KProcess;
+	K3Process *p = theProcess = new K3Process;
 
 	*p << newfs;
 	*p << "-q";
@@ -881,19 +873,19 @@ void Ext2Filesystem::exec()
 	}
 }
 
-void Ext2Filesystem::processStdOut(KProcess *, char *b, int l)
+void Ext2Filesystem::processStdOut(K3Process *, char *b, int l)
 {
 #ifdef ANY_BSD
     // ### TODO: do some checks
 #elif defined(ANY_LINUX)
     QString s ( QString::fromLatin1( b, l ) );
-    kdDebug(KFAREA) << s << endl;
-    if (s.find("mounted")!=-1) // "/dev/fd0 is mounted; will not make a filesystem here!"
+    kDebug(KFAREA) << s ;
+    if (s.contains("mounted")) // "/dev/fd0 is mounted; will not make a filesystem here!"
     {
         emit status(i18n("Floppy is mounted.\nYou need to unmount the floppy first."),-1);
         return;
     }
-    else if (s.find("busy")!=-1) // "Device or resource busy"
+    else if (s.contains("busy")) // "Device or resource busy"
     {
         emit status(i18n("Device busy.\nPerhaps you need to unmount the floppy first."),-1);
         return;
@@ -904,7 +896,7 @@ void Ext2Filesystem::processStdOut(KProcess *, char *b, int l)
 
 
 #ifdef ANY_LINUX
-/* static */ QString MinixFilesystem::newfs = QString::null ;
+/* static */ QString MinixFilesystem::newfs = QString();
 
 MinixFilesystem::MinixFilesystem(QObject *parent) :
 	FloppyAction(parent)
@@ -912,7 +904,7 @@ MinixFilesystem::MinixFilesystem(QObject *parent) :
 	DEBUGSETUP;
 	runtimeCheck();
 	theProcessName="mkfs.minix";
-	setName("Minix2Filesystem");
+	setObjectName("Minix2Filesystem");
 }
 
 /* static */ bool MinixFilesystem::runtimeCheck()
@@ -930,11 +922,11 @@ bool MinixFilesystem::configure(bool v,bool l,const QString &lbl)
 	doLabel=l;
 	if (l)
 	{
-		label=lbl.stripWhiteSpace();
+		label=lbl.trimmed();
 	}
 	else
 	{
-		label=QString::null;
+		label.clear();
 	}
 
 	return true;
@@ -959,7 +951,7 @@ void MinixFilesystem::exec()
 	}
 
 	if (theProcess) delete theProcess;
-	KProcess *p = theProcess = new KProcess;
+	K3Process *p = theProcess = new K3Process;
 
 	*p << newfs;
 
@@ -975,16 +967,16 @@ void MinixFilesystem::exec()
 	}
 }
 
-void MinixFilesystem::processStdOut(KProcess *, char *b, int l)
+void MinixFilesystem::processStdOut(K3Process *, char *b, int l)
 {
     QString s ( QString::fromLatin1( b, l ) );
-    kdDebug(KFAREA) << s << endl;
-    if (s.find("mounted")!=-1) // "mkfs.minix: /dev/fd0 is mounted; will not make a filesystem here!"
+    kDebug(KFAREA) << s ;
+    if (s.contains("mounted")) // "mkfs.minix: /dev/fd0 is mounted; will not make a filesystem here!"
     {
         emit status(i18n("Floppy is mounted.\nYou need to unmount the floppy first."),-1);
         return;
     }
-    else if (s.find("busy")!=-1) // "Device or resource busy"
+    else if (s.contains("busy")) // "Device or resource busy"
     {
         emit status(i18n("Device busy.\nPerhaps you need to unmount the floppy first."),-1);
         return;
