@@ -24,27 +24,28 @@
 #define PRINTCONTROLLER_H
 
 // Kakao gui
-#include <kviewcontroller.h>
+#include <abstractxmlguicontroller.h>
 
 class KAction;
-class KXmlGuiWindow;
+class KXMLGUIClient;
 class PrintTool;
 
 
-class PrintController : public KViewController
+class PrintController : public AbstractXmlGuiController
 {
   Q_OBJECT
 
   public:
-    explicit PrintController( KXmlGuiWindow *window );
+    explicit PrintController( KXMLGUIClient* guiClient );
     virtual ~PrintController();
 
-  public: // KViewController API
-    virtual void setView( KAbstractView *view );
+  public: // AbstractXmlGuiController API
+    virtual void setTargetModel( AbstractModel* model );
 
   protected:
     KAction *mPrintAction;
 
     PrintTool *mPrintTool;
 };
+
 #endif
